<script setup>

import AdminAuthenticatedLayout from '@/Layouts/AdminAuthenticatedLayout.vue';
import { ref, onMounted, computed } from 'vue';
import { Head, usePage, useForm } from '@inertiajs/vue3';
import NavLink from '@/Components/NavLink.vue';

const page = usePage();
const carMakes = computed(() => page.props.carMakes.data || []);
const loading = computed(() => page.props.loading || false);
const perPageOptions = [10, 20, 50]; // Adjust as needed
const perPage = ref(perPageOptions[0]);
const firstpage = ref(null);
const lastpage = ref(null);
const nextpage = ref(null);
const previouspage = ref(null);
const totalPages = ref(null);
const currentPage = ref(null);
const urlPerPage = ref(page.props.per_page);
const flashMessage = ref('');

if(perPage != urlPerPage) {
    perPage.value = urlPerPage.value;
}

const form = useForm({
    name: '',
});

// const sortBy = (key) => {
//   // Add your sorting logic here
//   // This is a simple example; you may need a more complex sorting mechanism
//   carMakes.value.sort((a, b) => (a[key] > b[key] ? 1 : -1));
// };

const sortDirections = ref({});
const sortBy = (key) => {
  // If the key has not been sorted before, default to ascending
  if (!sortDirections.value[key]) {
    sortDirections.value[key] = 'asc';
  } else {
    // If it was ascending before, now make it descending, and vice versa
    sortDirections.value[key] = sortDirections.value[key] === 'asc' ? 'desc' : 'asc';
  }

  const direction = sortDirections.value[key];

  carMakes.value.sort((a, b) => {
    if (a[key] < b[key]) {
      return direction === 'asc' ? -1 : 1;
    }
    if (a[key] > b[key]) {
      return direction === 'asc' ? 1 : -1;
    }
    return 0;
  });
};

const sortedCarMakes = computed(() => carMakes.value);

const changePerPage = () => {
    window.location.href = getLinkUrl();
};

const getLinkUrl = () => {
  return `/admin/products/allmakes?per_page=${perPage.value}`;
};

const editCarMake = (make) => {
  window.location.href = `/admin/product/make/edit/${make.id}`;
};

const deleteCarMake = (make) => {
  const carMakeID = make.id

  if (confirm('Are you sure you want to delete this?')) {
    form.post(route('admin.products.delete.make',{id: carMakeID}), {
        onSuccess: () => {
            flashMessage.value = "Car Make deleted successfully!";
        },
        onError: (error) => {
            console.error(error);
        }
    });
  }
};

onMounted(() => {
    const query = usePage().props;
    firstpage.value = query.carMakes.first_page_url;
    lastpage.value = query.carMakes.last_page_url;
    nextpage.value = query.carMakes.next_page_url;
    previouspage.value = query.carMakes.prev_page_url;
    totalPages.value = query.carMakes.last_page;
    currentPage.value = query.carMakes.current_page;
});
</script>

<template>
    <Head title="All Makes" />

    <AdminAuthenticatedLayout>
        <template #header>
            <div class="flex">
                <h2 class="font-semibold text-xl text-gray-800 leading-tight">Car Make's
                    <NavLink :href="route('admin.products.addmake')" :active="route().current('admin.products.addmake')">
                        + Add Make
                    </NavLink>
                </h2>
            </div>
        </template>

        <div class="py-12 container">
            <div v-if="flashMessage" class="mx-auto sm:px-6 lg:px-8 font-bold text-red-600">
                <div class="form-row mb-6">
                    <div class="col-md-6">
                        <h4>{{ flashMessage }}</h4>
                    </div>
                </div>
            </div>

            <div class="content-box sm:rounded-lg">
                <label for="perPageSelect">Per Page </label>
                <select id="perPageSelect" class="sm:mx-3 sm:mb-6" v-model="perPage" @change="changePerPage">
                    <option v-for="option in perPageOptions" :key="option" :value="option">
                        {{ option }}
                    </option>
                </select>
                <nav class="flex" style="width:200px;display: inline-block;float:right;">
                    <ul class="pagination" style="float:right;">
                        <li class="page-item">
                            <a class="page-link" :href="firstpage" v-if="firstpage && currentPage != totalPages"><span aria-hidden="true">&laquo;</span></a>
                        </li>
                        <li class="page-item">
                            <a class="page-link" :href="previouspage + '&per_page='+perPage" v-if="previouspage">Prev</a>
                        </li>
                        <li class="page-item" style="width: 80px;text-align: center;">
                            <a class="page-link"> {{ currentPage }} of {{ totalPages }}</a>
                        </li>
                        <li class="page-item">
                            <a class="page-link" :href="nextpage + '&per_page='+perPage" v-if="nextpage">Next</a>
                        </li>
                        <li class="page-item">
                            <a class="page-link" :href="lastpage" v-if="lastpage && currentPage != totalPages"><span aria-hidden="true">&raquo;</span></a>
                        </li>
                    </ul>
                </nav>
                <div v-if="loading">Loading...</div>
                <table v-else-if="carMakes && carMakes.length" class="table table-striped">
                    <thead>
                        <tr>
                        <th @click="sortBy('make')">Make</th>
                        <th @click="sortBy('year')">Year</th>
                        <th>Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr v-for="make in sortedCarMakes" :key="make.id">
                        <td>{{ make.name }}</td>
                        <td>{{ make.year }}</td>
                        <td>
                            <button class="px-3" @click="editCarMake(make)"><i class="fa fa-pen text-green-600"></i></button>
                            <button class="mx-3" @click="deleteCarMake(make)"><i class="fa fa-trash text-red-600"></i></button>
                        </td>
                        </tr>
                    </tbody>
                </table>
                <p v-else>No Car Makes found.</p>
            </div>
        </div>
    </AdminAuthenticatedLayout>
</template>
